function logimap6_selfsim_f2
% ============================================================= 65
% function logimap6_selfsim_f2                       2021/11/29
% Illustrates self-similar nature of the map: upon stretching,
% a portion of f2 repeats the behavior of the whole map.  The
% basis for the renormalization argument.
%
% Note that the super-stable cycle occurs for the value of r
% such that:
%            f(f(0.5)) = 0.5   AND   f(0.5) neq 0.5
%
% Since f(0.5) = r/4 this
% means:  r neq 2
% and     0.5 = f(r/4) = r^2*(1-r/4)/4.
% Factoring out the root r=2 leaves a quadratic with roots
% r = 1 \pm sqrt(5), only one of which satisfies 0 <= r <= 4.
% Thus
% Super-stable period 2 cycle occurs for r = 1+sqrt(5) ~ 3.24
% ============================================================= 65
LiW = 'LineWidth';   LW = 2;   FtS = 'FontSize';
x = (0:400)/400;   rc = 1+sqrt(5);
r = [1.5, 2, 2.6, 3, 3.2, rc, 3.4, 3.65];
% -------------------------------- Start.
N   = length(r);   n=1;   GO = 1;
%
while GO > 0;
  y = logimap(x, r(n), 2);
  plot(x, y, '-b', LiW, LW); hold on; grid on; zoom on;
  plot([0, 1], [0, 1], '-r', LiW, LW);
  TxT = 'Second iterate for r = ';
  title(['{\bf ', TxT, num2str(r(n)), '}'], FtS, 18)
  xlabel('{\bf x}', FtS, 18)
  ylabel('{\bf y}', FtS, 18, 'Rotation', 0)
  axis([0 1 0 1])
  if r(n) > 2;
    lin = [1/r(n), 1-1/r(n)];
    leu = (1-1/r(n))*[1, 1];
    led = (1/r(n))*[1, 1];
    plot(lin, leu, '-g', LiW, 2)
    plot(lin, led, '-g', LiW, 2)
    plot(led, lin, '-g', LiW, 2)
    plot(leu, lin, '-g', LiW, 2)
  end
  if abs(r(n)-rc) < 1e-4;
    xlabel('{\bf super-stable two cycle}', FtS, 18)
  end
  axis square
%
% Now advance or go back.
%
  y = input('   --- Return to go forward, 0 to go backwards: ');
  if isempty(y); n = n+1; else; n=n-1; end;
  if n > N; GO = -1; end
  if n < 1; n = n+1; end
  hold off
end
%
% ============================================================= 65
%
% ============================================================= 65
function y = logimap(x, r, n) % Map; x = array; r = scalar.
%                             % n = iterate #
% ------------------------------------------------------------- 65
y = r*x.*(1-x);
if nargin < 3; n=1;  end;
if n > 1.1; y = logimap(y, r, n-1); end
%
% ============================================================= 65
%
% ============================================================= 65
function LMcobweb(xi, N, r) % Plots N steps of the cobweb for
%                           % the logimap, starting at xi.
% xi can be a vector.
% Assumes N > 0;   0 <= r <= 4;   and   0 <= xi < = 1.
% Assumes "hold on" in figure when called.
% ------------------------------------------------------------- 65
LiW = 'LineWidth';   LW = 2;   Ns = length(xi);
for m=1:Ns
  x = xi(m);   y = logimap(x, r);
  plot([x, x], [0, y], '-g', LiW, LW)
  for n=2:N
    plot([x, y], [y, y], '-g', LiW, LW);
    x = y;   y = logimap(x, r);
    plot([x, x], [x, y], '-g', LiW, LW)
  end
  plot([x, y], [y, y], '-g', LiW, LW)
end
%
% ============================================================= 65
%
% ============================================================= 65
function y = LMpremap(xi, r) % Find the points y that get
%                            % mapped to xi by the logimap.
% xi can be a vector.
% Assumes 0 <= r <= 4;   and   0 <= xi < = 1.
% ------------------------------------------------------------- 65
I1 = find(xi < r/4);   I2 = find(xi == r/4);   y = [];
% Note: no pre-image for xi > r/4, and just one for xi = r/4;
if ~isempty(I1);   y = sqrt(1/4-xi(I1)/r);
                   y = [0.5-y, 0.5+y];   end
if ~isempty(I2);   y = [y, 0.5];         end
% Prune out duplicates.
y = sort(y);  GO = 1;
while GO > 0;
  L = length(y);
  I = find(y(1:L-1) == y(2:L));
  if isempty(I); GO = -1;
  else  y(I) = [];
  end
end
% ============================================================= 65
%
% ============================================================= 65
% EOF
